package com.goldenwater.slaj.eutr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eutr.mapper.BisEutrExamMapper;
import com.goldenwater.slaj.eutr.domain.BisEutrExam;
import com.goldenwater.slaj.eutr.service.IBisEutrExamService;

@Service
public class BisEutrExamServiceImpl implements IBisEutrExamService {
    @Autowired
    private BisEutrExamMapper bisEutrExamMapper;

    @Override
    public BisEutrExam selectBisEutrExamByGuid(String guid) {
        return bisEutrExamMapper.selectBisEutrExamByGuid(guid);
    }

    @Override
    public List<BisEutrExam> selectBisEutrExamList(BisEutrExam bisEutrExam) {
        return bisEutrExamMapper.selectBisEutrExamList(bisEutrExam);
    }

    @Override
    public int insertBisEutrExam(BisEutrExam bisEutrExam) {
        return bisEutrExamMapper.insertBisEutrExam(bisEutrExam);
    }

    @Override
    public int updateBisEutrExam(BisEutrExam bisEutrExam) {
        return bisEutrExamMapper.updateBisEutrExam(bisEutrExam);
    }

    @Override
    public int deleteBisEutrExamByGuid(String guid) {
        return bisEutrExamMapper.deleteBisEutrExamByGuid(guid);
    }

    @Override
    public int deleteBisEutrExamByGuids(String[] guids) {
        return bisEutrExamMapper.deleteBisEutrExamByGuids(guids);
    }
}
